@@ -232,18 +232,32 @@ def lgb_model_train(X_train,y_train,X_test,y_test,params=None,metric='average_pr
 
     watchlist = [d_train,d_valid]
     
-    print("--------------- lgb_model_train params -------------------")
-    print(params)
-    print("--------------- lgb_model_train params -------------------")
-    model = lgb.train(params,   
-                  keep_training_booster=True, # guarda los hiperparametros
-                  num_boost_round = num_rounds,
-                  train_set=d_train,
-                  valid_names = ['data_train','data_valid'],
-                  feval=feval,
-                  valid_sets=watchlist,
-                  callbacks=[log_evaluation(log),early_stopping(early_stop)]
-                 )
+    if early_stop is None:
+        
+        model = lgb.train(params,   
+                      keep_training_booster=True, # guarda los hiperparametros
+                      num_boost_round = num_rounds,
+                      train_set=d_train,                      
+                      feval=feval,                      
+                      callbacks=[log_evaluation(log)]
+                     )        
+
+    else:
+        
+        
+        print("--------------- lgb_model_train params -------------------")
+        print(params)
+        print("--------------- lgb_model_train params -------------------")
+        model = lgb.train(params,   
+                      keep_training_booster=True, # guarda los hiperparametros
+                      num_boost_round = num_rounds,
+                      train_set=d_train,
+                      valid_names = ['data_train','data_valid'],
+                      feval=feval,
+                      valid_sets=watchlist,
+                      callbacks=[log_evaluation(log),early_stopping(early_stop)]
+                     )
+
     
     return model
 
